@@ -23,8 +23,6 @@ if version.parse(pgmpy.__version__)>=version.parse("0.1.13"):
 else:
     from pgmpy.estimators import ConstraintBasedEstimator
 
-# from packaging import version
-# from bnlearn.bnlearn import _dag2adjmat
 import bnlearn
 
 
@@ -48,7 +46,7 @@ def fit(df, methodtype='hc', scoretype='bic', black_list=None, white_list=None,
             a. chi-square test
         3. Hybrid structure learning (The combination of both techniques) (MMHC)
 
-    Score-based Structure Learning
+    Score-based Structure Learning.
     This approach construes model selection as an optimization task. It has two building blocks:
     A scoring function sD:->R that maps models to a numerical score, based on how well they fit to a given data set D.
     A search strategy to traverse the search space of possible models M and select a model with optimal score.
@@ -78,7 +76,7 @@ def fit(df, methodtype='hc', scoretype='bic', black_list=None, white_list=None,
         In case of filtering on nodes, the search is limited to those edges. The resulting model will then only contain nodes that are in white_list.
         Works only in case of methodtype='hc' See also paramter: `bw_list_method`
     bw_list_method : list of str or tuple, (default : None)
-        A list of edges can be passed as `black_list` or `white_list` to exclude or to limit the search. 
+        A list of edges can be passed as `black_list` or `white_list` to exclude or to limit the search.
             * 'edges' : [('A', 'B'), ('C','D'), (...)] This option is limited to only methodtype='hc'
             * 'nodes' : ['A', 'B', ...] Filter the dataframe based on the nodes for `black_list` or `white_list`. Filtering can be done for every methodtype/scoretype.
     max_indegree : int, (default : None)
@@ -104,9 +102,10 @@ def fit(df, methodtype='hc', scoretype='bic', black_list=None, white_list=None,
 
     Examples
     --------
+    >>> # Import bnlearn
     >>> import bnlearn as bn
     >>>
-    >>> # Load asia DAG
+    >>> # Load DAG
     >>> model = bn.import_DAG('asia')
     >>>
     >>> # plot ground truth
@@ -118,6 +117,9 @@ def fit(df, methodtype='hc', scoretype='bic', black_list=None, white_list=None,
     >>> # Structure learning of sampled dataset
     >>> model_sl = bn.structure_learning.fit(df, methodtype='hc', scoretype='bic')
     >>>
+    >>> # Compute edge strength using chi-square independence test
+    >>> model_sl = bn.independence_test(model_sl, df)
+    >>>
     >>> # Plot based on structure learning of sampled data
     >>> bn.plot(model_sl, pos=G['pos'])
     >>>
@@ -127,7 +129,7 @@ def fit(df, methodtype='hc', scoretype='bic', black_list=None, white_list=None,
     """
     out = []
     # Set config
-    config = {'method':methodtype, 'scoring':scoretype, 'black_list':black_list, 'white_list':white_list, 'bw_list_method':bw_list_method, 'max_indegree':max_indegree, 'tabu_length':tabu_length, 'epsilon':epsilon, 'max_iter':max_iter, 'root_node':root_node, 'class_node':class_node, 'fixed_edges':fixed_edges, 'return_all_dags':return_all_dags, 'verbose':verbose}
+    config = {'method': methodtype, 'scoring': scoretype, 'black_list': black_list, 'white_list': white_list, 'bw_list_method': bw_list_method, 'max_indegree': max_indegree, 'tabu_length': tabu_length, 'epsilon': epsilon, 'max_iter': max_iter, 'root_node': root_node, 'class_node': class_node, 'fixed_edges': fixed_edges, 'return_all_dags': return_all_dags, 'verbose': verbose}
     # Make some checks
     config = _make_checks(df, config, verbose=verbose)
     # Make sure columns are of type string
@@ -183,7 +185,8 @@ def fit(df, methodtype='hc', scoretype='bic', black_list=None, white_list=None,
         out = _treesearch(df, config['method'], config['root_node'], class_node=config['class_node'], verbose=config['verbose'])
 
     # Store
-    out['adjmat'] = bnlearn._dag2adjmat(out['model'])
+    out['model_edges'] = list(out['model'].edges())
+    out['adjmat'] = bnlearn.dag2adjmat(out['model'])
     out['config'] = config
 
     # return
@@ -194,7 +197,7 @@ def fit(df, methodtype='hc', scoretype='bic', black_list=None, white_list=None,
 def _make_checks(df, config, verbose=3):
     assert isinstance(pd.DataFrame(), type(df)), 'df must be of type pd.DataFrame()'
     if not np.isin(config['scoring'], ['bic', 'k2', 'bdeu']): raise Exception('"scoretype=%s" is invalid.' %(config['scoring']))
-    if not np.isin(config['method'], ['naivebayes','nb', 'tan', 'cl', 'chow-liu', 'hc', 'ex', 'cs', 'exhaustivesearch', 'hillclimbsearch', 'constraintsearch']): raise Exception('"methodtype=%s" is invalid.' %(config['method']))
+    if not np.isin(config['method'], ['naivebayes', 'nb', 'tan', 'cl', 'chow-liu', 'hc', 'ex', 'cs', 'exhaustivesearch', 'hillclimbsearch', 'constraintsearch']): raise Exception('"methodtype=%s" is invalid.' %(config['method']))
 
     if isinstance(config['white_list'], str):
         config['white_list'] = [config['white_list']]
@@ -215,14 +218,14 @@ def _make_checks(df, config, verbose=3):
     if config['fixed_edges'] is None:
         config['fixed_edges']=set()
 
-    #### Remove this block in future (21-10-2021)
+    # Remove this block in future (21-10-2021)
     if config['bw_list_method']=='filter':
         if verbose>=2: print('[bnlearn] >Warning: The parameter bw_list_method="filter" is changed into bw_list_method="nodes". The old naming will be removed in future releases.')
         config['bw_list_method'] = "nodes"
     if config['bw_list_method']=='enforce':
         if verbose>=2: print('[bnlearn] >Warning: The parameter bw_list_method="enforce" is changed into bw_list_method="edges". The old naming will be removed in future releases.')
         config['bw_list_method'] = "edges"
-    #### End remove block
+    # End remove block
 
     # Show warnings
     if (config['bw_list_method'] is None) and ((config['black_list'] is not None) or (config['white_list'] is not None)):
@@ -279,7 +282,6 @@ def _naivebayes(df, root_node, estimator_type=None, feature_vars=None, dependent
     # Store
     out={}
     out['model']=model
-    out['model_edges']=model.edges()
     # Return
     return(out)
 
@@ -333,7 +335,6 @@ def _treesearch(df, estimator_type, root_node, class_node=None, verbose=3):
 
     # Store
     out['model']=model
-    out['model_edges']=model.edges()
     # Return
     return(out)
 
@@ -362,7 +363,7 @@ def _constraintsearch(df, significance_level=0.05, verbose=3):
         2. Orient compelled edges to obtain partially directed acyclid graph (PDAG; I-equivalence class of DAGs) - `skeleton_to_pdag()`
         3. Extend DAG pattern to a DAG by conservatively orienting the remaining edges in some way - `pdag_to_dag()`
 
-        Step 1.&2. form the so-called PC algorithm, see [2], page 550. PDAGs are `DirectedGraph`s, that may contain both-way edges, to indicate that the orientation for the edge is not determined.
+        The first two steps form the so-called PC algorithm, see [2], page 550. PDAGs are `DirectedGraph`s, that may contain both-way edges, to indicate that the orientation for the edge is not determined.
 
     """
     out = {}
@@ -390,10 +391,9 @@ def _constraintsearch(df, significance_level=0.05, verbose=3):
     out['dag'] = dag
     out['dag_edges'] = dag.edges()
 
-    # Search using "estimate()" method provides a shorthand for the three steps above and directly returns a "BayesianModel"
+    # Search using "estimate()" method provides a shorthand for the three steps above and directly returns a "BayesianNetwork"
     best_model = model.estimate(significance_level=significance_level)
     out['model'] = best_model
-    out['model_edges'] = best_model.edges()
 
     if verbose>=4: print(best_model.edges())
     return(out)
@@ -441,7 +441,6 @@ def _hillclimbsearch(df, scoretype='bic', black_list=None, white_list=None, max_
 
     # Store
     out['model']=best_model
-    out['model_edges']=best_model.edges()
     # Return
     return(out)
 
@@ -449,7 +448,7 @@ def _hillclimbsearch(df, scoretype='bic', black_list=None, white_list=None, max_
 # %% ExhaustiveSearch
 def _exhaustivesearch(df, scoretype='bic', return_all_dags=False, verbose=3):
     """Exhaustivesearch.
-    
+
     Description
     ------------
     The first property makes exhaustive search intractable for all but very
@@ -488,7 +487,6 @@ def _exhaustivesearch(df, scoretype='bic', return_all_dags=False, verbose=3):
     best_model = model.estimate()
     # Store
     out['model']=best_model
-    out['model_edges']=best_model.edges()
 
     # Compute all possible DAGs
     if return_all_dags:
